XEP-0502: MUC Activity Indicator
================================

.. module:: slixmpp.plugins.xep_0502

.. autoclass:: XEP_0502
    :members:
    :exclude-members: session_bind, plugin_init, plugin_end
